@@ -480,12 +480,12 @@ cmd_parser.add_argument("-ns", "--numSmooths", type=int, default=0, metavar="INT
 
 cmd_parser.add_argument("-gs", "--gsBbox", action="store_true", help="""
 
-   Use Ghostscript to find the bounding boxes for the pages.  The alternative
-   is to explicitly render the PDF pages to image files and calculate bounding
-   boxes from the images.  This method tends to be much faster, but it does not
-   work with scanned PDF documents.  It also does not allow for choosing the
-   threshold value, applying blurs, etc.  Any resolution options are passed to
-   the Ghostscript bbox device.  This option requires that Ghostscript be
+   Use Ghostscript to find the bounding boxes for the pages.  (The default is
+   to explicitly render the PDF pages to image files and calculate bounding
+   boxes from the images.)  This method tends to be much faster, but it does
+   not work with scanned PDF documents.  It also does not allow for choosing
+   the threshold value, applying blurs, etc.  Any resolution options are passed
+   to the Ghostscript bbox device.  This option requires that Ghostscript be
    available in the PATH as "gswin32c.exe" or "gswin64c.exe" on Windows, or as
    "gs" on Linux.  When this option is set the PIL image library for Python is
    not required.^^n""")
@@ -561,7 +561,7 @@ cmd_parser.add_argument("-r", "--restore", action="store_true", help="""
    option.  Saving in the ArtBoxes can be disabled by using the '--noundosave'
    option.^^n""")
 
-# TODO maybe later an option to choose which box to save to, or none, rather
+# Todo maybe later: an option to choose which box to save to, or none, rather
 # than just turn off ArtBox.
 cmd_parser.add_argument("-A", "--noundosave", action="store_true", help="""
 
@@ -772,6 +772,11 @@ cmd_parser.add_argument("-ppp", "--pdftoppmPath", type=str, metavar="PATH",
    No globbing is done.  Useful when the program is in a nonstandard
    location.^^n""")
 
+cmd_parser.add_argument("--version", action="store_true", help="""
+
+   Return the pdfCropMargins version number and exit immediately.  All
+   other options are ignored.^^n""")
+
 cmd_parser.add_argument("-wcdf", "--writeCropDataToFile", type=str,
                         default="", metavar="FILEPATH", help="""
 
